@@ -250,7 +250,7 @@ static const char *scope_declare(struct scope *s, const char *token, const size_
 {
     const struct cli_element *el = cli_hashtab_insert(&s->id_map, token, len, (const cli_element_data)(state->var_uniq++));
     /* cli_hashtab_insert either finds an already existing entry, or allocates a
-	 * new one, we return the allocated string */
+     * new one, we return the allocated string */
     return el ? el->key : NULL;
 }
 
@@ -259,13 +259,13 @@ static const char *scope_use(struct scope *s, const char *token, const size_t le
     const struct cli_element *el = cli_hashtab_find(&s->id_map, token, len);
     if (el) {
         /* identifier already found in current scope,
-		 * return here to avoid overwriting uniq id */
+         * return here to avoid overwriting uniq id */
         return el->key;
     }
     /* identifier not yet in current scope's hashtab, add with ID -1.
-	 * Later if we find a declaration it will automatically assign a uniq ID
-	 * to it. If not, we'll know that we have to push ID == -1 tokens to an
-	 * outer scope.*/
+     * Later if we find a declaration it will automatically assign a uniq ID
+     * to it. If not, we'll know that we have to push ID == -1 tokens to an
+     * outer scope.*/
     el = cli_hashtab_insert(&s->id_map, token, len, (const cli_element_data)-1);
     return el ? el->key : NULL;
 }
@@ -564,7 +564,6 @@ static void decode_de(yystype *params[], struct text_buffer *txtbuf)
     const char *o;
     const char **tokens;
 
-    memset(txtbuf, 0, sizeof(*txtbuf));
     if (!p || !k)
         return;
     for (o = k; *o; o++)
@@ -622,6 +621,8 @@ static void handle_de(yystype *tokens, size_t start, const size_t cnt, const cha
     size_t i, nesting = 1, j;
     yystype *parameters[6];
     const size_t parameters_cnt = 6;
+    yystype *first              = NULL;
+    yystype *last               = NULL;
 
     for (i = start; i < cnt; i++) {
         if (tokens[i].type == TOK_FUNCTION) {
@@ -649,13 +650,19 @@ static void handle_de(yystype *tokens, size_t start, const size_t cnt, const cha
                 for (j = 0; j < parameters_cnt && i < cnt; j++) {
                     parameters[j] = &tokens[i++];
                     if (j != parameters_cnt - 1)
-                        while (tokens[i].type != TOK_COMMA && i < cnt) i++;
+                        while (i < cnt && tokens[i].type != TOK_COMMA) i++;
                     else
-                        while (tokens[i].type != TOK_PAR_CLOSE && i < cnt) i++;
+                        while (i < cnt && tokens[i].type != TOK_PAR_CLOSE) i++;
                     i++;
                 }
-                if (j == parameters_cnt)
+                if (j == parameters_cnt) {
+                    if (NULL == first) {
+                        first = parameters[0];
+                    }
+                    last = parameters[parameters_cnt - 1];
+
                     decode_de(parameters, &res->txtbuf);
+                }
             }
         }
     } else {
@@ -666,17 +673,23 @@ static void handle_de(yystype *tokens, size_t start, const size_t cnt, const cha
         for (j = 0; j < parameters_cnt && i < cnt; j++) {
             parameters[j] = &tokens[i++];
             if (j != parameters_cnt - 1)
-                while (tokens[i].type != TOK_COMMA && i < cnt) i++;
+                while (i < cnt && tokens[i].type != TOK_COMMA) i++;
             else
-                while (tokens[i].type != TOK_PAR_CLOSE && i < cnt) i++;
+                while (i < cnt && tokens[i].type != TOK_PAR_CLOSE) i++;
             i++;
         }
-        if (j == parameters_cnt)
+        if (j == parameters_cnt) {
+            if (NULL == first) {
+                first = parameters[0];
+            }
+            last = parameters[parameters_cnt - 1];
+
             decode_de(parameters, &res->txtbuf);
+        }
     }
-    if (parameters[0] && parameters[parameters_cnt - 1]) {
-        res->pos_begin = parameters[0] - tokens;
-        res->pos_end   = parameters[parameters_cnt - 1] - tokens + 1;
+    if (first && last) {
+        res->pos_begin = first - tokens;
+        res->pos_end   = last - tokens + 1;
         if (tokens[res->pos_end].type == TOK_BRACKET_OPEN &&
             tokens[res->pos_end + 1].type == TOK_BRACKET_CLOSE &&
             tokens[res->pos_end + 2].type == TOK_PAR_CLOSE)
@@ -800,6 +813,7 @@ static void run_decoders(struct parser_state *state)
     for (i = 0; i < tokens->cnt; i++) {
         const char *cstring = TOKEN_GET(&tokens->data[i], cstring);
         struct decode_result res;
+        memset(&(res.txtbuf), 0, sizeof(res.txtbuf));
         res.pos_begin = res.pos_end = 0;
         res.append                  = 0;
         if (tokens->data[i].type == TOK_FUNCTION && i + 13 < tokens->cnt) {
@@ -818,7 +832,7 @@ static void run_decoders(struct parser_state *state)
                    cstring &&
                    !strcmp("dF", cstring) && tokens->data[i + 1].type == TOK_PAR_OPEN) {
             /* TODO: also match signature of dF function (possibly
-		   * declared using unescape */
+             * declared using unescape */
 
             handle_df(tokens->data, i + 2, &res);
         } else if (i + 2 < tokens->cnt && tokens->data[i].type == TOK_IDENTIFIER_NAME &&
@@ -839,7 +853,7 @@ static void run_decoders(struct parser_state *state)
                 cli_js_process_buffer(state, res.txtbuf.data, res.txtbuf.pos);
                 --state->rec;
             }
-            free(res.txtbuf.data);
+            FREE(res.txtbuf.data);
             /* state->tokens still refers to the embedded/nested context here */
             if (!res.append) {
                 if (CL_EARG == replace_token_range(&parent_tokens, res.pos_begin, res.pos_end, &state->tokens)) {
@@ -901,7 +915,7 @@ void cli_js_parse_done(struct parser_state *state)
     }
 
     /* we had to close unfinished strings, parenthesis,
-	 * so that the folders/decoders can run properly */
+     * so that the folders/decoders can run properly */
     run_folders(&state->tokens);
     run_decoders(state);
 
@@ -978,7 +992,7 @@ void cli_js_process_buffer(struct parser_state *state, const char *buf, size_t n
 
     if (!state->global) {
         /* this state has either not been initialized,
-		 * or cli_js_parse_done() was already called on it */
+         * or cli_js_parse_done() was already called on it */
         cli_warnmsg(MODULE "invalid state\n");
         return;
     }
@@ -1000,7 +1014,7 @@ void cli_js_process_buffer(struct parser_state *state, const char *buf, size_t n
                 leng = yyget_leng(state->scanner);
                 if (current->last_token == TOK_DOT) {
                     /* this is a member name, don't normalize
-					*/
+                     */
                     TOKEN_SET(&val, string, cli_strdup(text));
                     val.type = TOK_UNNORM_IDENTIFIER;
                 } else {
@@ -1057,9 +1071,9 @@ void cli_js_process_buffer(struct parser_state *state, const char *buf, size_t n
                     case WaitParameterList:
                     case InsideFunctionDecl:
                         /* in a syntactically correct
-						 * file, we would already be in
-						 * the Base state when we see a {
-						 */
+                         * file, we would already be in
+                         * the Base state when we see a {
+                         */
                         current->fsm_state = Base;
                         /* fall-through */
                     case InsideVar:
@@ -1080,7 +1094,7 @@ void cli_js_process_buffer(struct parser_state *state, const char *buf, size_t n
                 if (!current->blocks) {
                     if (current->parent) {
                         /* add dummy FUNCTION token to
-						 * mark function end */
+                         * mark function end */
                         TOKEN_SET(&val, cstring, "}");
                         add_token(state, &val);
                         TOKEN_SET(&val, scope, NULL);
@@ -1105,17 +1119,17 @@ void cli_js_process_buffer(struct parser_state *state, const char *buf, size_t n
             case TOK_COMMA:
                 if (current->fsm_state == InsideInitializer && current->brackets == 0 && current->blocks == 0) {
                     /* initializer ended only if we
-					 * encountered a comma, and [] are
-					 * balanced.
-					 * This avoids switching state on:
-					 * var x = [4,y,u];*/
+                     * encountered a comma, and [] are
+                     * balanced.
+                     * This avoids switching state on:
+                     * var x = [4,y,u];*/
                     current->fsm_state = InsideVar;
                 }
                 break;
             case TOK_SEMICOLON:
                 if (current->brackets == 0 && current->blocks == 0) {
                     /* avoid switching state on unbalanced []:
-					 * var x = [test;testi]; */
+                     * var x = [test;testi]; */
                     current->fsm_state = Base;
                 }
                 break;
@@ -1724,7 +1738,7 @@ static int yylex(YYSTYPE *lvalp, yyscan_t scanner)
             scanner->pos++;
         }
         /* its not necesarely an infloop if it changed
-		 * state, and it shouldn't infloop between states */
+         * state, and it shouldn't infloop between states */
     }
     scanner->lastpos    = scanner->pos;
     scanner->last_state = scanner->state;
@@ -1801,7 +1815,7 @@ static int yylex(YYSTYPE *lvalp, yyscan_t scanner)
             case SinglelineComment:
                 while (scanner->pos < scanner->insize) {
                     /* htmlnorm converts \n to space, so
-					 * stop on space too */
+                     * stop on space too */
                     if (in[scanner->pos] == '\n' || in[scanner->pos] == ' ')
                         break;
                     scanner->pos++;
