@@ -73,7 +73,7 @@
  * in re-enabling affected modules.
  */
 
-#define CL_FLEVEL 144
+#define CL_FLEVEL 151
 #define CL_FLEVEL_DCONF CL_FLEVEL
 #define CL_FLEVEL_SIGTOOL CL_FLEVEL
 
@@ -175,6 +175,10 @@ typedef struct bitset_tag {
     unsigned long length;
 } bitset_t;
 
+typedef struct image_fuzzy_hash {
+    uint8_t hash[8];
+} image_fuzzy_hash_t;
+
 typedef struct recursion_level_tag {
     cli_file_t type;
     size_t size;
@@ -182,8 +186,9 @@ typedef struct recursion_level_tag {
     uint32_t recursion_level_buffer;      /* Which buffer layer in scan recursion. */
     uint32_t recursion_level_buffer_fmap; /* Which fmap layer in this buffer. */
     bool is_normalized_layer;             /* Indicates that the layer should be skipped when checking container and intermediate types. */
+    image_fuzzy_hash_t image_fuzzy_hash;  /* Used for image/graphics files to store a fuzzy hash. */
+    bool calculated_image_fuzzy_hash;     /* Used for image/graphics files to store a fuzzy hash. */
 } recursion_level_t;
-// #define CONTAINER_FLAG_VALID 0x01
 
 /* internal clamav context */
 typedef struct cli_ctx_tag {
@@ -200,7 +205,6 @@ typedef struct cli_ctx_tag {
     unsigned int scannedfiles;
     unsigned int found_possibly_unwanted;
     unsigned int corrupted_input;
-    unsigned int img_validate;
     recursion_level_t *recursion_stack; /* Array of recursion levels used as a stack. */
     uint32_t recursion_stack_size;      /* stack size must == engine->max_recursion_level */
     uint32_t recursion_level;           /* Index into recursion_stack; current fmap recursion level from start of scan. */
@@ -328,15 +332,15 @@ struct cl_engine {
     /* Limits */
     uint32_t maxscantime;         /* Time limit (in milliseconds) */
     uint64_t maxscansize;         /* during the scanning of archives this size
-				           * will never be exceeded
-				           */
+                                   * will never be exceeded
+                                   */
     uint64_t maxfilesize;         /* compressed files will only be decompressed
-				           * and scanned up to this size
-				           */
+                                   * and scanned up to this size
+                                   */
     uint32_t max_recursion_level; /* maximum recursion level for archives */
     uint32_t maxfiles;            /* maximum number of files to be scanned
-				           * within a single archive
-				           */
+                                   * within a single archive
+                                   */
     /* This is for structured data detection.  You can set the minimum
      * number of occurrences of an CC# or SSN before the system will
      * generate a notification.
@@ -833,6 +837,12 @@ void cli_infomsg(const cli_ctx *ctx, const char *fmt, ...) __attribute__((format
 void cli_infomsg(const cli_ctx *ctx, const char *fmt, ...);
 #endif
 
+#ifdef __GNUC__
+void cli_infomsg_simple(const char *fmt, ...) __attribute__((format(printf, 1, 2)));
+#else
+void cli_infomsg_simple(const char *fmt, ...);
+#endif
+
 void cli_logg_setup(const cli_ctx *ctx);
 void cli_logg_unsetup(void);
 
@@ -860,12 +870,22 @@ void cli_logg_unsetup(void);
 #define __hot__
 #endif
 
-#define cli_dbgmsg (!UNLIKELY(cli_get_debug_flag())) ? (void)0 : cli_dbgmsg_internal
+#ifdef __GNUC__
+inline void cli_dbgmsg(const char *str, ...) __attribute__((format(printf, 1, 2)));
+#else
+inline void cli_dbgmsg(const char *str, ...);
+#endif
 
 #ifdef __GNUC__
-void cli_dbgmsg_internal(const char *str, ...) __attribute__((format(printf, 1, 2)));
+void cli_dbgmsg_no_inline(const char *str, ...) __attribute__((format(printf, 1, 2)));
 #else
-void cli_dbgmsg_internal(const char *str, ...);
+void cli_dbgmsg_no_inline(const char *str, ...);
+#endif
+
+#ifdef __GNUC__
+size_t cli_eprintf(const char *str, ...) __attribute__((format(printf, 1, 2)));
+#else
+size_t cli_eprintf(const char *str, ...);
 #endif
 
 #ifdef HAVE_CLI_GETPAGESIZE
