@@ -276,6 +276,231 @@ class TC(testcase.TestCase):
             'Test.Case.BC.PDF.hook FOUND',
         ]
         self.verify_output(output.out, expected=expected_results)
+
+    def test_clamscan_11_allmatch_hash_sigs(self):
+        self.step_name('Test that each type of hash sig is detected in all-match mode')
+
+        os.mkdir(str(TC.path_db / 'allmatch-test-sigs'))
+
+        (TC.path_db / 'allmatch-test-sigs' / 'clam.hdb').write_text(
+            "aa15bcf478d165efd2065190eb473bcb:544:Test.MD5.Hash:73\n"
+            "aa15bcf478d165efd2065190eb473bcb:*:Test.MD5.Hash.NoSize:73\n"
+        )
+        (TC.path_db / 'allmatch-test-sigs' / 'clam.hsb').write_text(
+            "71e7b604d18aefd839e51a39c88df8383bb4c071dc31f87f00a2b5df580d4495:544:Test.Sha256.Hash:73\n"
+            "71e7b604d18aefd839e51a39c88df8383bb4c071dc31f87f00a2b5df580d4495:*:Test.Sha256.Hash.NoSize:73\n"
+            "62dd70f5e7530e0239901ac186f1f9ae39292561:544:Test.Sha1.Hash:73\n"
+            "62dd70f5e7530e0239901ac186f1f9ae39292561:*:Test.Sha1.NoSize:73\n"
+        )
+        (TC.path_db / 'allmatch-test-sigs' / 'clam.imp').write_text(
+            "98c88d882f01a3f6ac1e5f7dfd761624:39:Test.Import.Hash\n"
+            "98c88d882f01a3f6ac1e5f7dfd761624:*:Test.Import.Hash.NoSize\n"
+        )
+        (TC.path_db / 'allmatch-test-sigs' / 'clam.mdb').write_text(
+            "512:23db1dd3f77fae25610b6a32701313ae:Test.PESection.Hash:73\n"
+            "*:23db1dd3f77fae25610b6a32701313ae:Test.PESection.Hash.NoSize:73\n"
+        )
+
+        testfiles = TC.path_build / 'unit_tests' / 'input' / 'clamav_hdb_scanfiles' / 'clam.exe'
+
+        command = '{valgrind} {valgrind_args} {clamscan} -d {path_db} {testfiles} --allmatch'.format(
+            valgrind=TC.valgrind, valgrind_args=TC.valgrind_args, clamscan=TC.clamscan,
+            path_db=TC.path_db / 'allmatch-test-sigs',
+            testfiles=testfiles,
+        )
+        output = self.execute_command(command)
+
+        assert output.ec == 1  # virus
+
+        expected_results = [
+            'Test.MD5.Hash.UNOFFICIAL FOUND',
+            'Test.MD5.Hash.NoSize.UNOFFICIAL FOUND',
+            'Test.Sha1.Hash.UNOFFICIAL FOUND',
+            'Test.Sha1.NoSize.UNOFFICIAL FOUND',
+            'Test.Sha256.Hash.UNOFFICIAL FOUND',
+            'Test.Sha256.Hash.NoSize.UNOFFICIAL FOUND',
+            'Test.PESection.Hash.UNOFFICIAL FOUND',
+            'Test.PESection.Hash.NoSize.UNOFFICIAL FOUND',
+            'Test.Import.Hash.UNOFFICIAL FOUND',
+            'Test.Import.Hash.NoSize.UNOFFICIAL FOUND',
+        ]
+        self.verify_output(output.out, expected=expected_results)
+
+    def test_clamscan_12_image_fuzzy_hash_sigs(self):
+        self.step_name('Test that each type of hash sig is detected in all-match mode')
+
+        os.mkdir(str(TC.path_db / 'image-fuzzy-hash-test-sigs'))
+
+        (TC.path_db / 'image-fuzzy-hash-test-sigs' / 'good.ldb').write_text(
+            "logo.png.good;Engine:150-255,Target:0;0;fuzzy_img#af2ad01ed42993c7#0\n"
+            "logo.png.bad.with.second.subsig;Engine:150-255,Target:0;0&1;deadbeef;fuzzy_img#af2ad01ed42993c7#0\n"
+            "logo.png.good.with.second.subsig;Engine:150-255,Target:0;0&1;49484452;fuzzy_img#af2ad01ed42993c7#0\n"
+        )
+
+        testfiles = TC.path_source / 'logo.png'
+
+        #
+        # First check with the good database in all-match mode.
+        #
+        command = '{valgrind} {valgrind_args} {clamscan} -d {path_db} {testfiles} --allmatch'.format(
+            valgrind=TC.valgrind, valgrind_args=TC.valgrind_args, clamscan=TC.clamscan,
+            path_db=TC.path_db / 'image-fuzzy-hash-test-sigs' / 'good.ldb',
+            testfiles=testfiles,
+        )
+        output = self.execute_command(command)
+
+        assert output.ec == 1  # virus
+
+        expected_stdout = [
+            'logo.png.good.UNOFFICIAL FOUND',
+            'logo.png.good.with.second.subsig.UNOFFICIAL FOUND',
+        ]
+        unexpected_stdout = [
+            'logo.png.bad.with.second.subsig.UNOFFICIAL FOUND',
+        ]
+        self.verify_output(output.out, expected=expected_stdout)
+
+        #
+        # Next check with the bad signatures
+        #
+
+        # Invalid hash
+        (TC.path_db / 'image-fuzzy-hash-test-sigs' / 'invalid-hash.ldb').write_text(
+            "logo.png.bad;Engine:150-255,Target:0;0;fuzzy_img#abcdef#0\n"
+        )
+        command = '{valgrind} {valgrind_args} {clamscan} -d {path_db} {testfiles} --allmatch'.format(
+            valgrind=TC.valgrind, valgrind_args=TC.valgrind_args, clamscan=TC.clamscan,
+            path_db=TC.path_db / 'image-fuzzy-hash-test-sigs' / 'invalid-hash.ldb',
+            testfiles=testfiles,
+        )
+        output = self.execute_command(command)
+
+        assert output.ec == 2  # error
+
+        expected_stderr = [
+            'LibClamAV Error: Failed to load',
+            'Invalid hash: Image fuzzy hash must be 16 characters in length: abcdef',
+        ]
+        unexpected_stdout = [
+            'logo.png.bad.UNOFFICIAL FOUND',
+        ]
+        self.verify_output(output.err, expected=expected_stderr)
+        self.verify_output(output.out, unexpected=unexpected_stdout)
+
+        # Unsupported hamming distance
+        (TC.path_db / 'image-fuzzy-hash-test-sigs' / 'invalid-ham.ldb').write_text(
+            "logo.png.bad;Engine:150-255,Target:0;0;fuzzy_img#af2ad01ed42993c7#1\n"
+        )
+        command = '{valgrind} {valgrind_args} {clamscan} -d {path_db} {testfiles} --allmatch'.format(
+            valgrind=TC.valgrind, valgrind_args=TC.valgrind_args, clamscan=TC.clamscan,
+            path_db=TC.path_db / 'image-fuzzy-hash-test-sigs' / 'invalid-ham.ldb',
+            testfiles=testfiles,
+        )
+        output = self.execute_command(command)
+
+        assert output.ec == 2  # error
+
+        expected_stderr = [
+            'LibClamAV Error: Failed to load',
+            'Invalid hamming distance: 1',
+        ]
+        unexpected_stdout = [
+            'logo.png.bad.UNOFFICIAL FOUND',
+        ]
+        self.verify_output(output.err, expected=expected_stderr)
+        self.verify_output(output.out, unexpected=unexpected_stdout)
+
+        # invalid algorithm
+        (TC.path_db / 'image-fuzzy-hash-test-sigs' / 'invalid-alg.ldb').write_text(
+            "logo.png.bad;Engine:150-255,Target:0;0;fuzzy_imgy#af2ad01ed42993c7#0\n"
+        )
+        command = '{valgrind} {valgrind_args} {clamscan} -d {path_db} {testfiles} --allmatch'.format(
+            valgrind=TC.valgrind, valgrind_args=TC.valgrind_args, clamscan=TC.clamscan,
+            path_db=TC.path_db / 'image-fuzzy-hash-test-sigs' / 'invalid-alg.ldb',
+            testfiles=testfiles,
+        )
+        output = self.execute_command(command)
+
+        assert output.ec == 2  # error
+
+        expected_stderr = [
+            'cli_loadldb: failed to parse subsignature 0 in logo.png',
+        ]
+        unexpected_stdout = [
+            'logo.png.bad.UNOFFICIAL FOUND',
+        ]
+        self.verify_output(output.err, expected=expected_stderr)
+        self.verify_output(output.out, unexpected=unexpected_stdout)
+
+    def test_clamscan_13_yara_regex(self):
+        self.step_name('Test yara signature - detect TAR file magic in a range')
+
+        db = TC.path_tmp / 'regex.yara'
+        db.write_text(
+            r'''
+rule regex
+{
+    meta:
+        author      = "Micah"
+        date        = "2022/03/12"
+        description = "Just a test"
+    strings:
+        $a = "/+eat/"                 /* <-- not a regex */
+        $b = /\$protein+=\([a-z]+\)/  /* <-- is a regex */
+    condition:
+        all of them
+}
+            '''
+        )
+        testfile = TC.path_tmp / 'regex.sample'
+        testfile.write_text('var $protein=(slugs); /+eat/ $protein')
+
+        command = '{valgrind} {valgrind_args} {clamscan} -d {path_db} {testfiles}'.format(
+            valgrind=TC.valgrind, valgrind_args=TC.valgrind_args, clamscan=TC.clamscan, path_db=db, testfiles=testfile,
+        )
+        output = self.execute_command(command)
+
+        assert output.ec == 1  # virus found
+
+        expected_results = [
+            'regex.sample: YARA.regex.UNOFFICIAL FOUND',
+            'Infected files: 1',
+        ]
+        self.verify_output(output.out, expected=expected_results)
+
+    def test_clamscan_14_xls_jpeg_detection(self):
+        self.step_name('Test that clamav can successfully alert on jpeg image extracted from XLS documents')
+        # Note: we aren't testing PNG because the attached PNG is not properly fuzzy-hashed by clamav, yet.
+
+        os.mkdir(str(TC.path_db / 'xls-jpeg-detection-sigs'))
+
+        (TC.path_db / 'image-fuzzy-hash-test-sigs' / 'good.ldb').write_text(
+            "logo.png.good;Engine:150-255,Target:0;0;fuzzy_img#ea0f85d0de719887#0\n"
+        )
+
+        testfiles = TC.path_source / 'unit_tests' / 'input' / 'other_scanfiles' / 'has_png_and_jpeg.xls'
+        command = '{valgrind} {valgrind_args} {clamscan} -d {path_db} {testfiles} --gen-json --debug --allmatch'.format(
+            valgrind=TC.valgrind, valgrind_args=TC.valgrind_args, clamscan=TC.clamscan,
+            path_db=TC.path_db / 'image-fuzzy-hash-test-sigs' / 'good.ldb',
+            testfiles=testfiles,
+        )
+        output = self.execute_command(command)
+
+        assert output.ec == 1  # no virus, no failures
+
+        expected_stderr = [
+            'Recognized PNG file',
+            'Recognized JPEG file',
+            '"FileMD5":"41e64a9ddb49690f0b6fbbd71362b1b3"',
+            '"FileMD5":"5341e0efde53a50c416b2352263e7693"',
+        ]
+        self.verify_output(output.err, expected=expected_stderr)
+
+        expected_stdout = [
+            'has_png_and_jpeg.xls: logo.png.good.UNOFFICIAL FOUND',
+        ]
+        self.verify_output(output.out, expected=expected_stdout)
+
     def test_clamscan_15_container(self):
         self.step_name('Test that clamav can successfully alert on jpeg image extracted from XLS documents')
         # Note: we aren't testing PNG because the attached PNG is not properly fuzzy-hashed by clamav, yet.
